@@ -1,7 +1,6 @@
-
 """
 # view processes which are using more than 2.5% CPU
-ps --xml -aux | xpath '//process/command/text()[../../cpu > 2.5]'
+ps --xml aux | xpath '//process/command/text()[../../cpu > 2.5]'
 """
 
 import sys
